@@ -175,7 +175,7 @@ main (int argc, char **argv)
   ac->strcasecmp = ac_strcasecmp;
 
   /* Making icon for systray */
-  sysicon = gtk_status_icon_new_from_file (JEEX_PATH_IMG "/jeex.png");
+  sysicon = gtk_status_icon_new_from_file (JEEX_PATH_IMG "/icon/jeex.png");
   gtk_status_icon_set_tooltip (sysicon, _("Allows you to show or hide the jeex\n" "main window."));
 
   /* Main Window */
@@ -183,13 +183,13 @@ main (int argc, char **argv)
   gtk_widget_set_name (jeex_main_window, "window");
   gtk_window_set_title (GTK_WINDOW (jeex_main_window), Jeex);
   gtk_window_set_default_size (GTK_WINDOW (jeex_main_window), 434, 506);
-  gtk_window_set_default_icon_from_file (JEEX_PATH_IMG "/jeex.png", NULL);
+  gtk_window_set_default_icon_from_file (JEEX_PATH_IMG "/images/jeex.png", NULL);
   gtk_widget_show (jeex_main_window);
 
   /* Parsing theme file. */
   if (g_file_test (g_strdup_printf ("%s/.config/jeex/jeex.rc", g_get_home_dir()), G_FILE_TEST_EXISTS))
       gtk_rc_parse (g_strdup_printf ("%s/.config/jeex/jeex.rc", g_get_home_dir()));
-
+	
   /* Main Table */
   table = gtk_table_new (6, 3, FALSE);
   gtk_container_add (GTK_CONTAINER (jeex_main_window), table);
